@@ -3,6 +3,10 @@
 config = None
 controllers = {}
 func_send = None
+ldap_conn = None
+ldap_serverpool = None
+ldap_mock = None
 models = None
 oauth = {}
+private_res = {}
 redis_conn = None
